package knosso;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * Title:        Cnosso
 * Description:  SImulazione di un labirinto
 * Copyright:    Copyright (c) 2001
 * Company:      Universit di Milano
 * @author Sara
 * @version 1.0
 */

public class CnossoFrame extends JFrame implements ComponentListener{
  JPanel contentPane;
  JMenuBar jMenuBar1 = new JMenuBar();
  JMenu jMenuFile = new JMenu();
  JMenuItem jMenuFileNew = new JMenuItem("Nuovo",new ImageIcon("new.gif"));
  JMenuItem jMenuFileClear = new JMenuItem("Pulisci",new ImageIcon("cut.gif"));
  JMenuItem jMenuFileOpen = new JMenuItem("Apri",new ImageIcon("open.gif"));
  JMenuItem jMenuFileSave = new JMenuItem("Salva",new ImageIcon("save.gif"));
  JMenuItem jMenuFileExit = new JMenuItem();
  JMenu jMenuSetup = new JMenu("Setup");
  JMenuItem jMenuSetupSize = new JMenuItem("Imposta Dimensione",new ImageIcon("paste.gif"));
  JCheckBoxMenuItem jMenuSetupTrace = new JCheckBoxMenuItem("Traccia soluzione");
  JMenu jMenuHelp = new JMenu();
  JMenuItem jMenuHelpSolve = new JMenuItem("Risolvi");
  JMenuItem jMenuHelpAbout = new JMenuItem();
  JLabel statusBar = new JLabel();
  BorderLayout borderLayout1 = new BorderLayout();

  Maze m = new Maze();

  /**Construct the frame*/
  public CnossoFrame() {
    enableEvents(AWTEvent.WINDOW_EVENT_MASK);
    try {
      jbInit();
    }
    catch(Exception e) {
      e.printStackTrace();
    }
    addComponentListener(this);
  }
  /**Component initialization*/
  private void jbInit() throws Exception  {
    //setIconImage(Toolkit.getDefaultToolkit().createImage(CnossoFrame.class.getResource("[Your Icon]")));
    contentPane = (JPanel) this.getContentPane();
    contentPane.setLayout(borderLayout1);
    this.setSize(new Dimension(502, 404));
    this.setTitle("Il Labirinto di Cnosso");
    statusBar.setText(" ");
    jMenuFile.setText("File");
    jMenuFileExit.setText("Exit");
    jMenuSetupTrace.setState(true);
    jMenuFileExit.addActionListener(new ActionListener()  {
      public void actionPerformed(ActionEvent e) {
        jMenuFileExit_actionPerformed(e);
      }
    });
    jMenuFileNew.addActionListener(new ActionListener()  {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Generating...");
        m.generate();
        statusBar.setText("Complete");
        m.requestFocus();
      }
    });
    jMenuFileClear.addActionListener(new ActionListener()  {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Clearing...");
        m.clearSolution();
        repaint();
        statusBar.setText("Cleared");
        m.requestFocus();
      }
    });
    jMenuFileSave.addActionListener(new ActionListener()  {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Saving...");
        m.save();
        statusBar.setText("Saved");
        m.requestFocus();
      }
    });
    jMenuFileOpen.addActionListener(new ActionListener()  {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Loading...");
        m.load();
        statusBar.setText("Loaded");
        m.requestFocus();
      }
    });
    jMenuSetupTrace.addActionListener(new ActionListener()  {
      public void actionPerformed(ActionEvent e) {
        m.setTrace();
        m.requestFocus();
        repaint();
      }});
    jMenuSetupSize.addActionListener(new ActionListener()  {
      public void actionPerformed(ActionEvent e) {
        m.requestDefaultFocus();
        JDialog f = new SizeDialog(CnossoFrame.this,"Set Size",true);
        f.setLocation( CnossoFrame.this.getLocation().x +
                          (CnossoFrame.this.getSize().width-f.getSize().width)/2,
                       CnossoFrame.this.getLocation().y+
                          (CnossoFrame.this.getSize().height-f.getSize().height)/3  );
        f.setVisible(true);
      }});
    jMenuHelp.setText("Help");
    jMenuHelpAbout.setText("About");
    jMenuHelpAbout.addActionListener(new ActionListener()  {
      public void actionPerformed(ActionEvent e) {
        jMenuHelpAbout_actionPerformed(e);
      }
    });
    jMenuHelpSolve.addActionListener(new ActionListener()  {
      public void actionPerformed(ActionEvent e) {
        statusBar.setText("Finding Solution...");
        m.findSolution();
        m.requestFocus();
      }
    });
    jMenuFile.add(jMenuFileNew);
    jMenuFile.add(jMenuFileClear);
    jMenuFile.add(new JSeparator());
    jMenuFile.add(jMenuFileOpen);
    jMenuFile.add(jMenuFileSave);
    jMenuFile.add(new JSeparator());
    jMenuFile.add(jMenuFileExit);

    jMenuSetup.add(jMenuSetupSize);
    jMenuSetup.add(new JSeparator());
    jMenuSetup.add(jMenuSetupTrace);
    jMenuHelp.add(jMenuHelpSolve);
    jMenuHelp.add(new JSeparator());
    jMenuHelp.add(jMenuHelpAbout);
    jMenuBar1.add(jMenuFile);
    jMenuBar1.add(jMenuSetup);
    jMenuBar1.add(jMenuHelp);
    this.setJMenuBar(jMenuBar1);
    contentPane.add(statusBar, BorderLayout.SOUTH);
    contentPane.add(m, BorderLayout.CENTER);

    //m.findSolution();
    //m.requestDefaultFocus();
  }
  /**File | Exit action performed*/
  public void jMenuFileExit_actionPerformed(ActionEvent e) {
    System.exit(0);
  }
  /**Help | About action performed*/
  public void jMenuHelpAbout_actionPerformed(ActionEvent e) {
    CnossoFrame_AboutBox dlg = new CnossoFrame_AboutBox(this);
    Dimension dlgSize = dlg.getPreferredSize();
    Dimension frmSize = getSize();
    Point loc = getLocation();
    dlg.setLocation((frmSize.width - dlgSize.width) / 2 + loc.x, (frmSize.height - dlgSize.height) / 2 + loc.y);
    dlg.setModal(true);
    dlg.show();
  }
  /**Overridden so we can exit when window is closed*/
  protected void processWindowEvent(WindowEvent e) {
    super.processWindowEvent(e);
    if (e.getID() == WindowEvent.WINDOW_CLOSING) {
      jMenuFileExit_actionPerformed(null);
    }
  }

  public void componentHidden(ComponentEvent e) {}
  public void componentMoved(ComponentEvent e) {
    if( m.getSize().width >0 ) m.drawMaze();
    m.requestFocus();
    repaint();
  }
  public void componentResized(ComponentEvent e) {
    if( m.getSize().width >0 ) m.drawMaze();
    m.requestFocus();
    repaint();
  }
  public void componentShown(ComponentEvent e) {
    if( m.getSize().width >0 ) m.drawMaze();
    m.requestFocus();
    repaint();
  }
}